@@ -1,8 +1,7 @@
-from ast import operator
 from typing import TYPE_CHECKING
-
 from pydantic import Field
 from typing_extensions import Literal
+from nonebot.typing import overrides
 
 from .base import Event
 
@@ -16,6 +15,10 @@ class RequestEvent(Event):
     message: str
     nick: str
 
+    @overrides(Event)
+    def get_type(self) -> Literal["message", "notice", "request", "meta_event"]:  # noqa
+        return 'request'
+
 
 class NewFriendRequestEvent(RequestEvent):
     """添加好友申请"""
@@ -40,7 +43,6 @@ class NewFriendRequestEvent(RequestEvent):
                               message=''
                           )
 
-
     async def reject(self,
                      bot: "Bot",
                      operate: Literal[1, 2] = 1,
@@ -93,7 +95,6 @@ class MemberJoinRequestEvent(RequestEvent):
                               operate=0,
                               message=''
                           )
-   
 
     async def reject(self,
                      bot: "Bot",
@@ -150,7 +151,6 @@ class BotInvitedJoinGroupRequestEvent(RequestEvent):
                               message=''
                           )
 
-
     async def reject(self, bot: "Bot", message: str = ""):
         """
         :说明:
